Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2743)

Unified Diff: chrome/common/chrome_notification_types.h

Issue 10836031: Remove Instant v1 API. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update history, title, favicon Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_renderer.gypi ('k') | chrome/common/instant_types.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_notification_types.h
diff --git a/chrome/common/chrome_notification_types.h b/chrome/common/chrome_notification_types.h
index 40d796552f4be082581e43e3cb90cc22223b03dd..002f93fb1ab7ffe810346bbb4e109d5c14c7907f 100644
--- a/chrome/common/chrome_notification_types.h
+++ b/chrome/common/chrome_notification_types.h
@@ -1097,13 +1097,16 @@ enum NotificationType {
// Sent each time the InstantController shows the InstantLoader.
NOTIFICATION_INSTANT_CONTROLLER_SHOWN,
- // Sent when an Instant preview is committed. The Source is the
- // TabContents containing the committed preview. There are no details.
+ // Sent each time the InstantController hides the InstantLoader.
+ NOTIFICATION_INSTANT_CONTROLLER_HIDDEN,
+
+ // Sent when an Instant preview is committed. The Source is the TabContents
+ // containing the committed preview. There are no details.
NOTIFICATION_INSTANT_COMMITTED,
- // Sent when the instant loader determines whether the page supports the
- // instant API or not. The details is a boolean indicating if the page
- // supports instant. The source is not used.
+ // Sent when the Instant loader determines whether the page supports the
+ // Instant API or not. The details is a boolean indicating if the page
+ // supports Instant. The source is not used.
NOTIFICATION_INSTANT_SUPPORT_DETERMINED,
// Sent when the CaptivePortalService checks if we're behind a captive portal.
« no previous file with comments | « chrome/chrome_renderer.gypi ('k') | chrome/common/instant_types.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698